@@ -12,7 +12,7 @@ Mojo::Util::monkey_patch(__PACKAGE__,
   ? sub { Mojo::ByteStream->new(Text::Markdown::markdown($_[0])) }
   : sub { $_[0] });
 
-our $VERSION = '2.01';
+our $VERSION = '2.02';
 my $X_RE = qr{^x-};
 
 has route     => sub {undef};
@@ -443,7 +443,11 @@ input/output validation to your L<Mojolicious> application based on a OpenAPI
 Have a look at the L</SEE ALSO> for references to more documentation, or jump
 right to the L<tutorial|Mojolicious::Plugin::OpenAPI::Guides::Tutorial>.
 
-L<Mojolicious::Plugin::OpenAPI> will replace L<Mojolicious::Plugin::Swagger2>.
+Currently v2 is very well supported, while v3 should be considered higly
+EXPERIMENTAL.
+
+Please report in L<issues|https://github.com/jhthorsen/json-validator/issues>
+or open pull requests to enhance the 3.0 support.
 
 =head1 HELPERS
 
@@ -663,8 +667,6 @@ the terms of the Artistic License version 2.0.
 
 =item * L<OpenAPI specification|https://openapis.org/specification>
 
-=item * L<Mojolicious::Plugin::Swagger2>.
-
 =back
 
 =cut
